==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/uk/rosterchanger.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>AddContactDialog</name>
    <message>
        <source>Please, authorize me to your presence.</source>
        <translation>Будь ласка, авторизуйте мене.</translation>
    </message>
    <message>
        <source>Add contact - %1</source>
        <translation>Додати контакт - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Відкрити вікно чату</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Повідомлення</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Надіслати повідомлення</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Показати vCard</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Прізвисько</translation>
    </message>
    <message>
        <source>Resolve nick name</source>
        <translation>Визначити прізвисько</translation>
    </message>
    <message>
        <source>Contact &lt;b&gt;%1&lt;/b&gt; already exists.</source>
        <translation>Контакт &lt;b&gt;%1&lt;/b&gt; уже існує.</translation>
    </message>
    <message>
        <source>* nested group delimiter - &apos;%1&apos;</source>
        <translation>* розділювач вкладених груп - &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Can&apos;t add contact &apos;&lt;b&gt;%1&lt;/b&gt;&apos; because it is not a valid Jabber ID</source>
        <translation>Неможливо додати контакт  &apos;&lt;b&gt;%1&lt;/b&gt;&apos; тому що це невірний Jabber ID</translation>
    </message>
</context>
<context>
    <name>AddContactDialogClass</name>
    <message>
        <source>Nick:</source>
        <translation>Прізвисько:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Група:</translation>
    </message>
    <message>
        <source>Contact:</source>
        <translation>Контакт:</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Авторизація</translation>
    </message>
    <message>
        <source>Subscribe to contact presence</source>
        <translation>Запитати авторизацію</translation>
    </message>
</context>
<context>
    <name>RosterChanger</name>
    <message>
        <source>Subscription requests</source>
        <translation>Запити авторизації</translation>
    </message>
    <message>
        <source>%1 wants to subscribe to your presence.</source>
        <translation>%1 хоче підписатись на ваш статус.</translation>
    </message>
    <message>
        <source>%1 unsubscribed from your presence.</source>
        <translation>%1 відписався від вашого статусу.</translation>
    </message>
    <message>
        <source>You are now unsubscribed from %1 presence.</source>
        <translation>%1 видалив вашу авторизацію на отримання статусу.</translation>
    </message>
    <message>
        <source>This group</source>
        <translation>В цю групу</translation>
    </message>
    <message>
        <source>Create new...</source>
        <translation>Створити нову...</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>В корінь</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Авторизація</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Надіслати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Request</source>
        <translation>Запитати</translation>
    </message>
    <message>
        <source>Copy contact</source>
        <translation>Копіювати контакт</translation>
    </message>
    <message>
        <source>Move contact</source>
        <translation>Перемістити контакт</translation>
    </message>
    <message>
        <source>Copy group</source>
        <translation>Копіювати групу</translation>
    </message>
    <message>
        <source>Move group</source>
        <translation>Перемістити групу</translation>
    </message>
    <message>
        <source>Refuse</source>
        <translation>Відмовитись</translation>
    </message>
    <message>
        <source>Copy to group</source>
        <translation>Копіювати в групу</translation>
    </message>
    <message>
        <source>Move to group</source>
        <translation>Перемістити в групу</translation>
    </message>
    <message>
        <source>Remove from group</source>
        <translation>Видалити з групи</translation>
    </message>
    <message>
        <source>Remove from roster</source>
        <translation>Видалити з ростеру</translation>
    </message>
    <message>
        <source>Remove group</source>
        <translation>Видалити групу</translation>
    </message>
    <message>
        <source>Remove contacts</source>
        <translation>Видалити контакти</translation>
    </message>
    <message>
        <source>Subscription message from %1</source>
        <translation>Повідомлення авторизації від %1</translation>
    </message>
    <message>
        <source>Subscription message</source>
        <translation>Повідомлення авторизації</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Перейменувати контакт</translation>
    </message>
    <message>
        <source>Enter name for: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Введіть ім&apos;я для: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Create new group</source>
        <translation>Створити нову групу</translation>
    </message>
    <message>
        <source>Enter group name:</source>
        <translation>Введіть ім&apos;я групи:</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Видалити контакт</translation>
    </message>
    <message>
        <source>You are assured that wish to remove a contact &lt;b&gt;%1&lt;/b&gt; from roster?</source>
        <translation>Ви впевнені, що хочете видалити контакт &lt;b&gt;%1&lt;/b&gt; з ростеру?</translation>
    </message>
    <message>
        <source>Rename group</source>
        <translation>Перейменувати групу</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Введіть нове ім&apos;я групи:</translation>
    </message>
    <message>
        <source>You are assured that wish to remove %1 contact(s) from roster?</source>
        <translation>Ви впевнені, що хочете видалити %1 контакт(ів) з ростеру?</translation>
    </message>
    <message>
        <source>You are now subscribed for %1 presence.</source>
        <translation>%1 авторизував вас на отримання статусу.</translation>
    </message>
    <message>
        <source>Add contact</source>
        <translation>Додати контакт</translation>
    </message>
    <message>
        <source>Subscribe contact</source>
        <translation>Авторизувати контакт</translation>
    </message>
    <message>
        <source>Unsubscribe contact</source>
        <translation>Видалити авторизацію</translation>
    </message>
    <message>
        <source>Subscribe for contact presence</source>
        <translation>Підписатись на отримання статусу контакту</translation>
    </message>
    <message>
        <source>You are assured that wish to subscribe for a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Ви впевнені, що хочете підписатись на отримання статусу контакту &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Unsubscribe from contact presence</source>
        <translation>Відписатись від отримання статусу контакту</translation>
    </message>
    <message>
        <source>You are assured that wish to unsubscribe from a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Ви впевнені, що хочете відписатись на отримання статусу контакту &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Roster Editor</source>
        <translation>Редактор ростеру</translation>
    </message>
    <message>
        <source>Allows to edit roster</source>
        <translation>Дозволяє редагувати ростер</translation>
    </message>
    <message>
        <source>Auto accept subscription requests</source>
        <translation>Автоматично приймати запроси на авторизацію</translation>
    </message>
    <message>
        <source>Auto unsubscribe contacts</source>
        <translation>Автоматично видаляти авторизацію</translation>
    </message>
    <message>
        <source>Ins</source>
        <comment>Add contact</comment>
        <translation>Ins</translation>
    </message>
    <message>
        <source>Rename contact/group</source>
        <translation>Видалити контакт/групу</translation>
    </message>
    <message>
        <source>F2</source>
        <comment>Rename contact/group</comment>
        <translation>F2</translation>
    </message>
    <message>
        <source>Remove contact/group from group</source>
        <translation>Видалити контакт/групу з групи</translation>
    </message>
    <message>
        <source>Del</source>
        <comment>Remove contact/group from group</comment>
        <translation>Del</translation>
    </message>
    <message>
        <source>Remove contact/group from roster</source>
        <translation>Видалити контакт/групу з ростеру</translation>
    </message>
    <message>
        <source>Shift+Del</source>
        <comment>Remove contact/group from roster</comment>
        <translation>Shift+Del</translation>
    </message>
    <message>
        <source>Add contact...</source>
        <translation>Додати контакт...</translation>
    </message>
    <message>
        <source>Blank Group</source>
        <translation>Пуста група</translation>
    </message>
    <message>
        <source>Roster management</source>
        <translation>Управління ростером</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialog</name>
    <message>
        <source>Subscription request - %1</source>
        <translation>Запит авторизації- %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Відкрити вікно чату</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Повідомлення</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Надіслати повідомлення</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Показати vCard</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialogClass</name>
    <message>
        <source>Add user to contact list</source>
        <translation>Додати користувача до ростеру</translation>
    </message>
    <message>
        <source>Authorize presence subscription</source>
        <translation>Авторизувати</translation>
    </message>
    <message>
        <source>Remove presence subscription</source>
        <translation>Видалити авторизацію</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/uk/rosterchanger.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>AddContactDialog</name>
    <message>
        <source>Please, authorize me to your presence.</source>
        <translation>Будь ласка, авторизуйте мене.</translation>
    </message>
    <message>
        <source>Add contact - %1</source>
        <translation>Додати контакт - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Відкрити вікно чату</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Повідомлення</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Надіслати повідомлення</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Показати vCard</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Прізвисько</translation>
    </message>
    <message>
        <source>Resolve nick name</source>
        <translation>Визначити прізвисько</translation>
    </message>
    <message>
        <source>Contact &lt;b&gt;%1&lt;/b&gt; already exists.</source>
        <translation>Контакт &lt;b&gt;%1&lt;/b&gt; уже існує.</translation>
    </message>
    <message>
        <source>* nested group delimiter - &apos;%1&apos;</source>
        <translation>* розділювач вкладених груп - &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Can&apos;t add contact &apos;&lt;b&gt;%1&lt;/b&gt;&apos; because it is not a valid Jabber ID</source>
        <translation>Неможливо додати контакт  &apos;&lt;b&gt;%1&lt;/b&gt;&apos; тому що це невірний Jabber ID</translation>
    </message>
</context>
<context>
    <name>AddContactDialogClass</name>
    <message>
        <source>Nick:</source>
        <translation>Прізвисько:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Група:</translation>
    </message>
    <message>
        <source>Contact:</source>
        <translation>Контакт:</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Авторизація</translation>
    </message>
    <message>
        <source>Subscribe to contact presence</source>
        <translation>Запитати авторизацію</translation>
    </message>
</context>
<context>
    <name>RosterChanger</name>
    <message>
        <source>%1 wants to subscribe to your presence.</source>
        <translation>%1 хоче підписатись на ваш статус.</translation>
    </message>
    <message>
        <source>%1 unsubscribed from your presence.</source>
        <translation>%1 відписався від вашого статусу.</translation>
    </message>
    <message>
        <source>You are now unsubscribed from %1 presence.</source>
        <translation>%1 видалив вашу авторизацію на отримання статусу.</translation>
    </message>
    <message>
        <source>This group</source>
        <translation>В цю групу</translation>
    </message>
    <message>
        <source>Create new...</source>
        <translation>Створити нову...</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>В корінь</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Авторизація</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Надіслати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Request</source>
        <translation>Запитати</translation>
    </message>
    <message>
        <source>Copy contact</source>
        <translation>Копіювати контакт</translation>
    </message>
    <message>
        <source>Move contact</source>
        <translation>Перемістити контакт</translation>
    </message>
    <message>
        <source>Copy group</source>
        <translation>Копіювати групу</translation>
    </message>
    <message>
        <source>Move group</source>
        <translation>Перемістити групу</translation>
    </message>
    <message>
        <source>Refuse</source>
        <translation>Відмовитись</translation>
    </message>
    <message>
        <source>Copy to group</source>
        <translation>Копіювати в групу</translation>
    </message>
    <message>
        <source>Move to group</source>
        <translation>Перемістити в групу</translation>
    </message>
    <message>
        <source>Remove from group</source>
        <translation>Видалити з групи</translation>
    </message>
    <message>
        <source>Remove from roster</source>
        <translation>Видалити з ростеру</translation>
    </message>
    <message>
        <source>Remove group</source>
        <translation>Видалити групу</translation>
    </message>
    <message>
        <source>Remove contacts</source>
        <translation>Видалити контакти</translation>
    </message>
    <message>
        <source>Subscription message from %1</source>
        <translation>Повідомлення авторизації від %1</translation>
    </message>
    <message>
        <source>Subscription message</source>
        <translation>Повідомлення авторизації</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Перейменувати контакт</translation>
    </message>
    <message>
        <source>Enter name for: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Введіть ім&apos;я для: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Create new group</source>
        <translation>Створити нову групу</translation>
    </message>
    <message>
        <source>Enter group name:</source>
        <translation>Введіть ім&apos;я групи:</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Видалити контакт</translation>
    </message>
    <message>
        <source>You are assured that wish to remove a contact &lt;b&gt;%1&lt;/b&gt; from roster?</source>
        <translation>Ви впевнені, що хочете видалити контакт &lt;b&gt;%1&lt;/b&gt; з ростеру?</translation>
    </message>
    <message>
        <source>Rename group</source>
        <translation>Перейменувати групу</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Введіть нове ім&apos;я групи:</translation>
    </message>
    <message>
        <source>You are now subscribed for %1 presence.</source>
        <translation>%1 авторизував вас на отримання статусу.</translation>
    </message>
    <message>
        <source>Add contact</source>
        <translation>Додати контакт</translation>
    </message>
    <message>
        <source>Subscribe contact</source>
        <translation>Авторизувати контакт</translation>
    </message>
    <message>
        <source>Unsubscribe contact</source>
        <translation>Видалити авторизацію</translation>
    </message>
    <message>
        <source>Subscribe for contact presence</source>
        <translation>Підписатись на отримання статусу контакту</translation>
    </message>
    <message>
        <source>You are assured that wish to subscribe for a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Ви впевнені, що хочете підписатись на отримання статусу контакту &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Unsubscribe from contact presence</source>
        <translation>Відписатись від отримання статусу контакту</translation>
    </message>
    <message>
        <source>You are assured that wish to unsubscribe from a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Ви впевнені, що хочете відписатись на отримання статусу контакту &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Roster Editor</source>
        <translation>Редактор ростеру</translation>
    </message>
    <message>
        <source>Allows to edit roster</source>
        <translation>Дозволяє редагувати ростер</translation>
    </message>
    <message>
        <source>Auto accept subscription requests</source>
        <translation>Автоматично приймати запроси на авторизацію</translation>
    </message>
    <message>
        <source>Auto unsubscribe contacts</source>
        <translation>Автоматично видаляти авторизацію</translation>
    </message>
    <message>
        <source>Ins</source>
        <comment>Add contact</comment>
        <translation>Ins</translation>
    </message>
    <message>
        <source>Rename contact/group</source>
        <translation>Видалити контакт/групу</translation>
    </message>
    <message>
        <source>F2</source>
        <comment>Rename contact/group</comment>
        <translation>F2</translation>
    </message>
    <message>
        <source>Remove contact/group from group</source>
        <translation>Видалити контакт/групу з групи</translation>
    </message>
    <message>
        <source>Del</source>
        <comment>Remove contact/group from group</comment>
        <translation>Del</translation>
    </message>
    <message>
        <source>Remove contact/group from roster</source>
        <translation>Видалити контакт/групу з ростеру</translation>
    </message>
    <message>
        <source>Shift+Del</source>
        <comment>Remove contact/group from roster</comment>
        <translation>Shift+Del</translation>
    </message>
    <message>
        <source>Add contact...</source>
        <translation>Додати контакт...</translation>
    </message>
    <message>
        <source>Blank Group</source>
        <translation>Пуста група</translation>
    </message>
    <message>
        <source>When receiving authorization request</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>You are assured that wish to remove &lt;b&gt;%n contact(s)&lt;/b&gt; from roster?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SubscriptionDialog</name>
    <message>
        <source>Subscription request - %1</source>
        <translation>Запит авторизації- %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Відкрити вікно чату</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Повідомлення</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Надіслати повідомлення</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Показати vCard</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialogClass</name>
    <message>
        <source>Add user to contact list</source>
        <translation>Додати користувача до ростеру</translation>
    </message>
    <message>
        <source>Authorize presence subscription</source>
        <translation>Авторизувати</translation>
    </message>
    <message>
        <source>Remove presence subscription</source>
        <translation>Видалити авторизацію</translation>
    </message>
</context>
</TS>
